@@ -177,10 +177,10 @@ test_that("infinity works", {
   expect_false(is.infinite(bigfloat(0)))
   expect_true(is.finite(bigfloat(0)))
 
-  expect_error(as.logical(bigfloat(Inf)), class = "vctrs_error_cast_lossy")
-  expect_error(as.logical(bigfloat(-Inf)), class = "vctrs_error_cast_lossy")
-  expect_error(as.integer(bigfloat(Inf)), class = "vctrs_error_cast_lossy")
-  expect_error(as.integer(bigfloat(-Inf)), class = "vctrs_error_cast_lossy")
+  expect_warning(as.logical(bigfloat(Inf)), class = "bignum_warning_cast_lossy")
+  expect_warning(as.logical(bigfloat(-Inf)), class = "bignum_warning_cast_lossy")
+  expect_warning(as.integer(bigfloat(Inf)), class = "bignum_warning_cast_lossy")
+  expect_warning(as.integer(bigfloat(-Inf)), class = "bignum_warning_cast_lossy")
   expect_equal(as.double(bigfloat(Inf)), Inf)
   expect_equal(as.double(bigfloat(-Inf)), -Inf)
   expect_equal(as.character(bigfloat(Inf)), "Inf")
